==> ark-23.08.4.tar.xz: ark-23.08.4/part/ark_part.json.cmake <==
{
    "KPlugin": {
        "Description": "Archive Handling Tool",
        "Description[ar]": "أداة التعامل مع الملفات المضغوطة",
        "Description[bg]": "Инструмент за обработка на архиви",
        "Description[ca@valencia]": "Eina de gestió d'arxius",
        "Description[ca]": "Eina de gestió d'arxius",
        "Description[cs]": "Program pro práci s archivy",
        "Description[eo]": "Arkivpritrakta Ilo",
        "Description[es]": "Herramienta de gestión de archivos comprimidos",
        "Description[eu]": "Artxiboak kudeatzeko tresna",
        "Description[fi]": "Arkistonkäsittelyohjelma",
        "Description[fr]": "Outil de manipulation d'archives",
        "Description[gl]": "Utilidade de manexo de arquivos.",
        "Description[ia]": "Instrumento de manear archivo",
        "Description[it]": "Strumento di gestione degli archivi",
        "Description[ka]": "არქივებთან სამუშაო ხელსაწყო",
        "Description[ko]": "압축 파일 처리 도구",
        "Description[nl]": "Hulpprogramma voor het beheren van archieven",
        "Description[nn]": "Verktøy for arkivhandsaming",
        "Description[pl]": "Program obsługi archiwów",
        "Description[pt]": "Ferramenta de Tratamento de Pacotes",
        "Description[pt_BR]": "Ferramenta de manipulação de arquivos",
        "Description[ru]": "Программа для работы с архивами",
        "Description[sl]": "Orodje za upravljanje arhivov",
        "Description[sv]": "Arkivhanteringsverktyg",
        "Description[tr]": "Arşiv İşleme Aracı",
        "Description[uk]": "Інструмент для роботи з архівами",
        "Description[x-test]": "xxArchive Handling Toolxx",
        "Description[zh_CN]": "压缩文件管理工具",
        "Description[zh_TW]": "封存檔處理工具",
        "Icon": "ark",
        "License": "GPL v2+",
        "MimeTypes": [
            "@SUPPORTED_ARK_MIMETYPES_JSON@"
        ],
        "Name": "Archiver",
        "Name[ar]": "المؤرشف",
        "Name[bg]": "Архиватор",
        "Name[ca@valencia]": "Arxivador",
        "Name[ca]": "Arxivador",
        "Name[cs]": "Archivátor",
        "Name[eo]": "Arkivilo",
        "Name[es]": "Archivador",
        "Name[eu]": "Artxibatzailea",
        "Name[fi]": "Arkistointi",
        "Name[fr]": "Archiveur",
        "Name[gl]": "Arquivador",
        "Name[ia]": "Archivaor",
        "Name[it]": "Utilità di archiviazione",
        "Name[ka]": "არქივატორი",
        "Name[ko]": "압축 도구",
        "Name[nl]": "Archiefgereedschap",
        "Name[nn]": "Arkivprogram",
        "Name[pl]": "Archiwizer",
        "Name[pt]": "Ark",
        "Name[pt_BR]": "Arquivador",
        "Name[ru]": "Архиватор",
        "Name[sl]": "Arhivar",
        "Name[sv]": "Arkiverare",
        "Name[ta]": "காப்பக உருவாக்கி",
        "Name[tr]": "Arşivleyici",
        "Name[uk]": "Архіватор",
        "Name[x-test]": "xxArchiverxx",
        "Name[zh_CN]": "压缩文件管理工具",
        "Name[zh_TW]": "封存工具",
        "ServiceTypes": [
            "KParts/ReadOnlyPart",
            "Browser/View"
        ],
        "Version": "@ARK_VERSION@",
        "Website": "https://utils.kde.org/projects/ark"
    }
}

==> ark_23.08.5.orig.tar.xz: ark-23.08.5/part/ark_part.json.cmake <==
{
    "KPlugin": {
        "Description": "Archive Handling Tool",
        "Description[ar]": "أداة التعامل مع الملفات المضغوطة",
        "Description[bg]": "Инструмент за обработка на архиви",
        "Description[ca@valencia]": "Eina de gestió d'arxius",
        "Description[ca]": "Eina de gestió d'arxius",
        "Description[cs]": "Program pro práci s archivy",
        "Description[de]": "Archiv-Verwaltung",
        "Description[eo]": "Arkivpritrakta Ilo",
        "Description[es]": "Herramienta de gestión de archivos comprimidos",
        "Description[eu]": "Artxiboak kudeatzeko tresna",
        "Description[fi]": "Arkistonkäsittelyohjelma",
        "Description[fr]": "Outil de manipulation d'archives",
        "Description[gl]": "Utilidade de manexo de arquivos.",
        "Description[ia]": "Instrumento de manear archivo",
        "Description[it]": "Strumento di gestione degli archivi",
        "Description[ja]": "アーカイブ処理ツール",
        "Description[ka]": "არქივებთან სამუშაო ხელსაწყო",
        "Description[ko]": "압축 파일 처리 도구",
        "Description[nl]": "Hulpprogramma voor het beheren van archieven",
        "Description[nn]": "Verktøy for arkivhandsaming",
        "Description[pl]": "Program obsługi archiwów",
        "Description[pt]": "Ferramenta de Tratamento de Pacotes",
        "Description[pt_BR]": "Ferramenta de manipulação de arquivos",
        "Description[ro]": "Utilitar de manipulare a arhivelor",
        "Description[ru]": "Программа для работы с архивами",
        "Description[sk]": "Nástroj na prácu s archívmi",
        "Description[sl]": "Orodje za upravljanje arhivov",
        "Description[sv]": "Arkivhanteringsverktyg",
        "Description[tr]": "Arşiv İşleme Aracı",
        "Description[uk]": "Інструмент для роботи з архівами",
        "Description[x-test]": "xxArchive Handling Toolxx",
        "Description[zh_CN]": "压缩文件管理工具",
        "Description[zh_TW]": "封存檔處理工具",
        "Icon": "ark",
        "License": "GPL v2+",
        "MimeTypes": [
            "@SUPPORTED_ARK_MIMETYPES_JSON@"
        ],
        "Name": "Archiver",
        "Name[ar]": "المؤرشف",
        "Name[bg]": "Архиватор",
        "Name[ca@valencia]": "Arxivador",
        "Name[ca]": "Arxivador",
        "Name[cs]": "Archivátor",
        "Name[de]": "Archivierer",
        "Name[eo]": "Arkivilo",
        "Name[es]": "Archivador",
        "Name[eu]": "Artxibatzailea",
        "Name[fi]": "Arkistointi",
        "Name[fr]": "Archiveur",
        "Name[gl]": "Arquivador",
        "Name[ia]": "Archivaor",
        "Name[it]": "Utilità di archiviazione",
        "Name[ja]": "アーカイバ",
        "Name[ka]": "არქივატორი",
        "Name[ko]": "압축 도구",
        "Name[nl]": "Archiefgereedschap",
        "Name[nn]": "Arkivprogram",
        "Name[pl]": "Archiwizer",
        "Name[pt]": "Ark",
        "Name[pt_BR]": "Arquivador",
        "Name[ro]": "Arhivator",
        "Name[ru]": "Архиватор",
        "Name[sk]": "Archivačný nástroj",
        "Name[sl]": "Arhivar",
        "Name[sv]": "Arkiverare",
        "Name[ta]": "காப்பக உருவாக்கி",
        "Name[tr]": "Arşivleyici",
        "Name[uk]": "Архіватор",
        "Name[x-test]": "xxArchiverxx",
        "Name[zh_CN]": "压缩文件管理工具",
        "Name[zh_TW]": "封存工具",
        "ServiceTypes": [
            "KParts/ReadOnlyPart",
            "Browser/View"
        ],
        "Version": "@ARK_VERSION@",
        "Website": "https://utils.kde.org/projects/ark"
    }
}
